<?php

if ( ! function_exists('kudos_qodef_blog_options_map') ) {

	function kudos_qodef_blog_options_map() {

		kudos_qodef_add_admin_page(
			array(
				'slug' => '_blog_page',
				'title' => esc_html__('Blog', 'kudos'),
				'icon' => 'fa fa-files-o'
			)
		);

		/**
		 * Blog Lists
		 */

		$custom_sidebars = kudos_qodef_get_custom_sidebars();

		$panel_blog_lists = kudos_qodef_add_admin_panel(
			array(
				'page' => '_blog_page',
				'name' => 'panel_blog_lists',
				'title' => esc_html__('Blog Lists', 'kudos')
			)
		);

		kudos_qodef_add_admin_field(array(
			'name'        => 'blog_list_type',
			'type'        => 'select',
			'label'       => esc_html__('Blog Layout for Archive Pages', 'kudos'),
			'description' => esc_html__('Choose a default blog layout', 'kudos'),
			'default_value' => 'standard',
			'parent'      => $panel_blog_lists,
			'options'     => array(
				'standard'				=> esc_html__('Blog: Standard', 'kudos'),
				'masonry' 				=> esc_html__('Blog: Masonry', 'kudos'),
				'masonry-full-width' 	=> esc_html__('Blog: Masonry Full Width', 'kudos'),
				'standard-whole-post' 	=> esc_html__('Blog: Standard Whole Post', 'kudos'),
				'gallery' 				=> esc_html__('Blog: Gallery', 'kudos'),
				'narrow' 				=> esc_html__('Blog: Narrow', 'kudos')
			)
		));

		kudos_qodef_add_admin_field(array(
			'name'        => 'archive_sidebar_layout',
			'type'        => 'select',
			'label'       => esc_html__('Archive and Category Sidebar', 'kudos'),
			'description' => esc_html__('Choose a sidebar layout for archived Blog Post Lists and Category Blog Lists', 'kudos'),
			'parent'      => $panel_blog_lists,
			'options'     => array(
				'default'			=> esc_html__('No Sidebar', 'kudos'),
				'sidebar-33-right'	=> esc_html__('Sidebar 1/3 Right', 'kudos'),
				'sidebar-25-right' 	=> esc_html__('Sidebar 1/4 Right', 'kudos'),
				'sidebar-33-left' 	=> esc_html__('Sidebar 1/3 Left', 'kudos'),
				'sidebar-25-left' 	=> esc_html__('Sidebar 1/4 Left', 'kudos'),
			)
		));


		if(count($custom_sidebars) > 0) {
			kudos_qodef_add_admin_field(array(
				'name' => 'blog_custom_sidebar',
				'type' => 'selectblank',
				'label' => esc_html__('Sidebar to Display', 'kudos'),
				'description' => esc_html__('Choose a sidebar to display on Blog Post Lists and Category Blog Lists. Default sidebar is "Sidebar Page"', 'kudos'),
				'parent' => $panel_blog_lists,
				'options' => kudos_qodef_get_custom_sidebars()
			));
		}


		kudos_qodef_add_admin_field(
			array(
				'type' => 'yesno',
				'name' => 'pagination',
				'default_value' => 'yes',
				'label' => esc_html__('Pagination', 'kudos'),
				'parent' => $panel_blog_lists,
				'description' => esc_html__('Enabling this option will display pagination links on bottom of Blog Post List', 'kudos'),
				'args' => array(
					'dependence' => true,
					'dependence_hide_on_yes' => '',
					'dependence_show_on_yes' => '#qodef_qodef_pagination_container'
				)
			)
		);

		$pagination_container = kudos_qodef_add_admin_container(
			array(
				'name' => 'qodef_pagination_container',
				'hidden_property' => 'pagination',
				'hidden_value' => 'no',
				'parent' => $panel_blog_lists,
			)
		);

		kudos_qodef_add_admin_field(
			array(
				'parent' => $pagination_container,
				'type' => 'text',
				'name' => 'blog_page_range',
				'default_value' => '',
				'label' => esc_html__('Pagination Range limit', 'kudos'),
				'description' => esc_html__('Enter a number that will limit pagination to a certain range of links', 'kudos'),
				'args' => array(
					'col_width' => 3
				)
			)
		);
		kudos_qodef_add_admin_field(
			array(
				'type' => 'selectblank',
				'name' => 'pagination_type',
				'default_value' => 'standard_pagination',
				'label' => esc_html__('Pagination Type', 'kudos'),
				'parent' => $pagination_container,
				'description' => esc_html__('Choose Pagination Type', 'kudos'),
				'options' => array(
					'standard_paginaton' => esc_html__('Standard Pagination', 'kudos'),
					'load_more_pagination' => esc_html__('Load More', 'kudos'),
                    'navigation'	=> esc_html__('Navigation', 'kudos')
				),
				'args' => array(
					'col_width' => 3
				)
			)
		);

		kudos_qodef_add_admin_field(
			array(
				'type' => 'selectblank',
				'name' => 'gallery_pagination_type',
				'default_value' => '',
				'label' => esc_html__('Gallery Pagination Type', 'kudos'),
				'parent' => $pagination_container,
				'description' => esc_html__('Choose Pagination Type for Gallery Blog Template', 'kudos'),
				'options' => array(
					'standard_pagination' => esc_html__('Standard Pagination', 'kudos'),
					'load_more_pagination' => esc_html__('Load More', 'kudos'),
					'navigation'	=> esc_html__('Navigation', 'kudos')
				),
				'args' => array(
					'col_width' => 3
				)
			)
		);

		kudos_qodef_add_admin_field(
			array(
				'type' => 'selectblank',
				'name' => 'masonry_pagination_type',
				'default_value' => '',
				'label' => esc_html__('Masonry Pagination Type', 'kudos'),
				'parent' => $pagination_container,
				'description' => esc_html__('Choose Pagination Type for Masonry Blog Template', 'kudos'),
				'options' => array(
					'standard_paginaton' => esc_html__('Standard Pagination', 'kudos'),
					'load_more_pagination' => esc_html__('Load More', 'kudos'),
					'navigation'	=> esc_html__('Navigation', 'kudos')
				),
				'args' => array(
					'col_width' => 3
				)
			)
		);

		kudos_qodef_add_admin_field(
			array(
				'type' => 'yesno',
				'name' => 'masonry_filter',
				'default_value' => 'no',
				'label' => esc_html__('Masonry Filter', 'kudos'),
				'parent' => $panel_blog_lists,
				'description' => esc_html__('Enabling this option will display category filter on Masonry and Masonry Full Width Templates', 'kudos'),
				'args' => array(
					'col_width' => 3
				)
			)
		);		
		kudos_qodef_add_admin_field(
			array(
				'type' => 'text',
				'name' => 'number_of_chars',
				'default_value' => '',
				'label' => esc_html__('Number of Words in Excerpt', 'kudos'),
				'parent' => $panel_blog_lists,
				'description' => esc_html__('Enter a number of words in excerpt (article summary)', 'kudos'),
				'args' => array(
					'col_width' => 3
				)
			)
		);
		kudos_qodef_add_admin_field(
			array(
				'type' => 'text',
				'name' => 'standard_number_of_chars',
				'default_value' => '',
				'label' => esc_html__('Standard Type Number of Words in Excerpt', 'kudos'),
				'parent' => $panel_blog_lists,
				'description' => esc_html__('Enter a number of words in excerpt (article summary)', 'kudos'),
				'args' => array(
					'col_width' => 3
				)
			)
		);
		kudos_qodef_add_admin_field(
			array(
				'type' => 'text',
				'name' => 'masonry_number_of_chars',
				'default_value' => '',
				'label' => esc_html__('Masonry Type Number of Words in Excerpt', 'kudos'),
				'parent' => $panel_blog_lists,
				'description' => esc_html__('Enter a number of words in excerpt (article summary)', 'kudos'),
				'args' => array(
					'col_width' => 3
				)
			)
		);

		kudos_qodef_add_admin_field(
			array(
				'type' => 'text',
				'name' => 'gallery_number_of_chars',
				'default_value' => '',
				'label' => esc_html__('Gallery Type Number of Words in Excerpt', 'kudos'),
				'parent' => $panel_blog_lists,
				'description' => esc_html__('Enter a number of words in excerpt (article summary)', 'kudos'),
				'args' => array(
					'col_width' => 3
				)
			)
		);

		kudos_qodef_add_admin_field(
			array(
				'type' => 'text',
				'name' => 'narrow_number_of_chars',
				'default_value' => '',
				'label' => esc_html__('Narrow Type Number of Words in Excerpt', 'kudos'),
				'parent' => $panel_blog_lists,
				'description' => esc_html__('Enter a number of words in excerpt (article summary)', 'kudos'),
				'args' => array(
					'col_width' => 3
				)
			)
		);

		/**
		 * Blog Single
		 */
		$panel_blog_single = kudos_qodef_add_admin_panel(
			array(
				'page' => '_blog_page',
				'name' => 'panel_blog_single',
				'title' => esc_html__('Blog Single', 'kudos')
			)
		);


		kudos_qodef_add_admin_field(array(
			'name'        => 'blog_single_sidebar_layout',
			'type'        => 'select',
			'label'       => 'Sidebar Layout',
			'description' => 'Choose a sidebar layout for Blog Single pages',
			'parent'      => $panel_blog_single,
			'options'     => array(
				'default'			=> esc_html__('No Sidebar', 'kudos'),
				'sidebar-33-right'	=> esc_html__('Sidebar 1/3 Right', 'kudos'),
				'sidebar-25-right' 	=> esc_html__('Sidebar 1/4 Right', 'kudos'),
				'sidebar-33-left' 	=> esc_html__('Sidebar 1/3 Left', 'kudos'),
				'sidebar-25-left' 	=> esc_html__('Sidebar 1/4 Left', 'kudos'),
			),
			'default_value'	=> 'default'
		));


		if(count($custom_sidebars) > 0) {
			kudos_qodef_add_admin_field(array(
				'name' => 'blog_single_custom_sidebar',
				'type' => 'selectblank',
				'label' => esc_html__('Sidebar to Display', 'kudos'),
				'description' => esc_html__('Choose a sidebar to display on Blog Single pages. Default sidebar is "Sidebar"', 'kudos'),
				'parent' => $panel_blog_single,
				'options' => kudos_qodef_get_custom_sidebars()
			));
		}

		kudos_qodef_add_admin_field(array(
			'name'          => 'blog_single_title_in_title_area',
			'type'          => 'yesno',
			'label'         => esc_html__('Show Post Title in Title Area', 'kudos'),
			'description'   => esc_html__('Enabling this option will show post title in title area on single post pages', 'kudos'),
			'parent'        => $panel_blog_single,
			'default_value' => 'no'
		));

		kudos_qodef_add_admin_field(array(
			'name' => 'blog_single_title_breadcrumbs_color',
			'type' => 'color',
			'label' => 'Title Breadcrumbs Color',
			'description' => 'Set breadcrumbs color for blog single title',
			'parent' => $panel_blog_single
		));
		
		kudos_qodef_add_admin_field(array(
			'name'          => 'blog_single_comments',
			'type'          => 'yesno',
			'label'         => esc_html__('Show Comments', 'kudos'),
			'description'   => esc_html__('Enabling this option will show comments on your page.', 'kudos'),
			'parent'        => $panel_blog_single,
			'default_value' => 'yes'
		));

		kudos_qodef_add_admin_field(array(
			'name'			=> 'blog_single_related_posts',
			'type'			=> 'yesno',
			'label'			=> esc_html__('Show Related Posts', 'kudos'),
			'description'   => esc_html__('Enabling this option will show related posts on your single post.', 'kudos'),
			'parent'        => $panel_blog_single,
			'default_value' => 'no'
		));

		kudos_qodef_add_admin_field(
			array(
				'type' => 'yesno',
				'name' => 'blog_single_navigation',
				'default_value' => 'no',
				'label' => esc_html__('Enable Prev/Next Single Post Navigation Links', 'kudos'),
				'parent' => $panel_blog_single,
				'description' => esc_html__('Enable navigation links through the blog posts (left and right arrows will appear)', 'kudos'),
				'args' => array(
					'dependence' => true,
					'dependence_hide_on_yes' => '',
					'dependence_show_on_yes' => '#qodef_qodef_blog_single_navigation_container'
				)
			)
		);

		$blog_single_navigation_container = kudos_qodef_add_admin_container(
			array(
				'name' => 'qodef_blog_single_navigation_container',
				'hidden_property' => 'blog_single_navigation',
				'hidden_value' => 'no',
				'parent' => $panel_blog_single,
			)
		);

		kudos_qodef_add_admin_field(
			array(
				'type'        => 'yesno',
				'name' => 'blog_navigation_through_same_category',
				'default_value' => 'no',
				'label'       => esc_html__('Enable Navigation Only in Current Category', 'kudos'),
				'description' => esc_html__('Limit your navigation only through current category', 'kudos'),
				'parent'      => $blog_single_navigation_container,
				'args' => array(
					'col_width' => 3
				)
			)
		);

		kudos_qodef_add_admin_field(
			array(
				'type' => 'yesno',
				'name' => 'blog_author_info',
				'default_value' => 'no',
				'label' => esc_html__('Show Author Info Box', 'kudos'),
				'parent' => $panel_blog_single,
				'description' => esc_html__('Enabling this option will display author name and descriptions on Blog Single pages', 'kudos'),
				'args' => array(
					'dependence' => true,
					'dependence_hide_on_yes' => '',
					'dependence_show_on_yes' => '#qodef_qodef_blog_single_author_info_container'
				)
			)
		);

		$blog_single_author_info_container = kudos_qodef_add_admin_container(
			array(
				'name' => 'qodef_blog_single_author_info_container',
				'hidden_property' => 'blog_author_info',
				'hidden_value' => 'no',
				'parent' => $panel_blog_single,
			)
		);

		kudos_qodef_add_admin_field(
			array(
				'type'        => 'yesno',
				'name' => 'blog_author_info_email',
				'default_value' => 'no',
				'label'       => esc_html__('Show Author Email', 'kudos'),
				'description' => esc_html__('Enabling this option will show author email', 'kudos'),
				'parent'      => $blog_single_author_info_container,
				'args' => array(
					'col_width' => 3
				)
			)
		);

	}

	add_action( 'kudos_qodef_options_map', 'kudos_qodef_blog_options_map',13);

}











