<?php

if ( ! function_exists('kudos_qodef_footer_options_map') ) {
	/**
	 * Add footer options
	 */
	function kudos_qodef_footer_options_map() {

		kudos_qodef_add_admin_page(
			array(
				'slug' => '_footer_page',
				'title' => esc_html__('Footer', 'kudos'),
				'icon' => 'fa fa-sort-amount-asc'
			)
		);

		$footer_panel = kudos_qodef_add_admin_panel(
			array(
				'title' => esc_html__('Footer', 'kudos'),
				'name' => 'footer',
				'page' => '_footer_page'
			)
		);

		kudos_qodef_add_admin_field(
			array(
				'type' => 'yesno',
				'name' => 'uncovering_footer',
				'default_value' => 'no',
				'label' => esc_html__('Uncovering Footer', 'kudos'),
				'description' => esc_html__('Enabling this option will make Footer gradually appear on scroll', 'kudos'),
				'parent' => $footer_panel,
			)
		);

		kudos_qodef_add_admin_field(
			array(
				'type' => 'yesno',
				'name' => 'footer_in_grid',
				'default_value' => 'yes',
				'label' => esc_html__('Footer in Grid', 'kudos'),
				'description' => esc_html__('Enabling this option will place Footer content in grid', 'kudos'),
				'parent' => $footer_panel,
			)
		);

		kudos_qodef_add_admin_field(
			array(
				'type' => 'yesno',
				'name' => 'show_footer_top',
				'default_value' => 'yes',
				'label' => esc_html__('Show Footer Top', 'kudos'),
				'description' => esc_html__('Enabling this option will show Footer Top area', 'kudos'),
				'args' => array(
					'dependence' => true,
					'dependence_hide_on_yes' => '',
					'dependence_show_on_yes' => '#qodef_show_footer_top_container'
				),
				'parent' => $footer_panel,
			)
		);

		$show_footer_top_container = kudos_qodef_add_admin_container(
			array(
				'name' => 'show_footer_top_container',
				'hidden_property' => 'show_footer_top',
				'hidden_value' => 'no',
				'parent' => $footer_panel
			)
		);

		kudos_qodef_add_admin_field(
			array(
				'type' => 'select',
				'name' => 'footer_top_columns',
				'default_value' => '4',
				'label' => esc_html__('Footer Top Columns', 'kudos'),
				'description' => esc_html__('Choose number of columns for Footer Top area', 'kudos'),
				'options' => array(
					'1' => esc_html__('1', 'kudos'),
					'2' => esc_html__('2', 'kudos'),
					'3' => esc_html__('3', 'kudos'),
					'5' => esc_html__('3(25%+25%+50%)', 'kudos'),
					'6' => esc_html__('3(50%+25%+25%)', 'kudos'),
					'4' => esc_html__('4', 'kudos')
				),
				'parent' => $show_footer_top_container,
			)
		);

		kudos_qodef_add_admin_field(
			array(
				'type' => 'select',
				'name' => 'footer_top_columns_alignment',
				'default_value' => '',
				'label' => esc_html__('Footer Top Columns Alignment', 'kudos'),
				'description' => esc_html__('Text Alignment in Footer Columns', 'kudos'),
				'options' => array(
					'left' => esc_html__('Left', 'kudos'),
					'center' => esc_html__('Center', 'kudos'),
					'right' => esc_html__('Right', 'kudos')
				),
				'parent' => $show_footer_top_container,
			)
		);

		kudos_qodef_add_admin_field(
			array(
				'type' => 'yesno',
				'name' => 'show_footer_bottom',
				'default_value' => 'yes',
				'label' => esc_html__('Show Footer Bottom', 'kudos'),
				'description' => esc_html__('Enabling this option will show Footer Bottom area', 'kudos'),
				'args' => array(
					'dependence' => true,
					'dependence_hide_on_yes' => '',
					'dependence_show_on_yes' => '#qodef_show_footer_bottom_container'
				),
				'parent' => $footer_panel,
			)
		);

		$show_footer_bottom_container = kudos_qodef_add_admin_container(
			array(
				'name' => 'show_footer_bottom_container',
				'hidden_property' => 'show_footer_bottom',
				'hidden_value' => 'no',
				'parent' => $footer_panel
			)
		);


		kudos_qodef_add_admin_field(
			array(
				'type' => 'select',
				'name' => 'footer_bottom_columns',
				'default_value' => '3',
				'label' => esc_html__('Footer Bottom Columns', 'kudos'),
				'description' => esc_html__('Choose number of columns for Footer Bottom area', 'kudos'),
				'options' => array(
					'1' => '1',
					'2' => '2',
					'3' => '3'
				),
				'parent' => $show_footer_bottom_container,
			)
		);

	}

	add_action( 'kudos_qodef_options_map', 'kudos_qodef_footer_options_map',5);

}