<?php

if ( ! function_exists( 'kudos_qodef_register_top_header_areas' ) ) {
	/**
	 * Registers widget areas for top header bar when it is enabled
	 */
	function kudos_qodef_register_top_header_areas() {
		if ( kudos_qodef_core_installed() ) {
			register_sidebar( array(
				'name'          => esc_html__( 'Top Bar Left', 'kudos' ),
				'id'            => 'qodef-top-bar-left',
				'before_widget' => '<div id="%1$s" class="widget %2$s qodef-top-bar-widget">',
				'after_widget'  => '</div>',
				'description'   => esc_html__( 'Widgets added here will appear on the left hand side in top bar', 'kudos' ),
			) );

			register_sidebar( array(
				'name'          => esc_html__( 'Top Bar Center', 'kudos' ),
				'id'            => 'qodef-top-bar-center',
				'before_widget' => '<div id="%1$s" class="widget %2$s qodef-top-bar-widget">',
				'after_widget'  => '</div>',
				'description'   => esc_html__( 'Widgets added here will appear in the center in the top bar', 'kudos' ),
			) );

			register_sidebar( array(
				'name'          => esc_html__( 'Top Bar Right', 'kudos' ),
				'id'            => 'qodef-top-bar-right',
				'before_widget' => '<div id="%1$s" class="widget %2$s qodef-top-bar-widget">',
				'after_widget'  => '</div>',
				'description'   => esc_html__( 'Widgets added here will appear on the right hand side in the top bar', 'kudos' ),
			) );
		}
	}

	add_action( 'widgets_init', 'kudos_qodef_register_top_header_areas' );
}

if ( ! function_exists( 'kudos_qodef_header_standard_widget_areas' ) ) {
	/**
	 * Registers widget areas for standard header type
	 */
	function kudos_qodef_header_standard_widget_areas() {
		if ( kudos_qodef_core_installed() ) {
			register_sidebar( array(
				'name'          => esc_html__( 'Right From Main Menu', 'kudos' ),
				'id'            => 'qodef-right-from-main-menu',
				'before_widget' => '<div id="%1$s" class="widget %2$s qodef-right-from-main-menu-widget">',
				'after_widget'  => '</div>',
				'description'   => esc_html__( 'Widgets added here will appear on the right hand side from the main menu', 'kudos' )
			) );
		}
	}

	add_action( 'widgets_init', 'kudos_qodef_header_standard_widget_areas' );
}

if ( ! function_exists( 'kudos_qodef_header_vertical_widget_areas' ) ) {
	/**
	 * Registers widget areas for vertical header
	 */
	function kudos_qodef_header_vertical_widget_areas() {
		if ( kudos_qodef_core_installed() ) {
			register_sidebar( array(
				'name'          => esc_html__( 'Vertical Area', 'kudos' ),
				'id'            => 'qodef-vertical-area',
				'before_widget' => '<div id="%1$s" class="widget %2$s qodef-vertical-area-widget">',
				'after_widget'  => '</div>',
				'description'   => esc_html__( 'Widgets added here will appear on the bottom of vertical menu', 'kudos' )
			) );
		}
	}

	add_action( 'widgets_init', 'kudos_qodef_header_vertical_widget_areas' );
}


if ( ! function_exists( 'kudos_qodef_register_mobile_header_areas' ) ) {
	/**
	 * Registers widget areas for mobile header
	 */
	function kudos_qodef_register_mobile_header_areas() {
		if ( kudos_qodef_is_responsive_on() && kudos_qodef_core_installed() ) {
			register_sidebar( array(
				'name'          => esc_html__( 'Right From Mobile Logo', 'kudos' ),
				'id'            => 'qodef-right-from-mobile-logo',
				'before_widget' => '<div id="%1$s" class="widget %2$s qodef-right-from-mobile-logo">',
				'after_widget'  => '</div>',
				'description'   => esc_html__( 'Widgets added here will appear on the right hand side from the mobile logo', 'kudos' )
			) );
		}
	}

	add_action( 'widgets_init', 'kudos_qodef_register_mobile_header_areas' );
}

if ( ! function_exists( 'kudos_qodef_register_sticky_header_areas' ) ) {
	/**
	 * Registers widget area for sticky header
	 */
	function kudos_qodef_register_sticky_header_areas() {
		if ( kudos_qodef_core_installed() ) {
			if ( in_array( kudos_qodef_options()->getOptionValue( 'header_behaviour' ), array(
				'sticky-header-on-scroll-up',
				'sticky-header-on-scroll-down-up'
			) ) ) {
				register_sidebar( array(
					'name'          => esc_html__( 'Sticky Right', 'kudos' ),
					'id'            => 'qodef-sticky-right',
					'before_widget' => '<div id="%1$s" class="widget %2$s qodef-sticky-right">',
					'after_widget'  => '</div>',
					'description'   => esc_html__( 'Widgets added here will appear on the right hand side in sticky menu', 'kudos' )
				) );
			}
		}
	}

	add_action( 'widgets_init', 'kudos_qodef_register_sticky_header_areas' );
}