<?php

if(!function_exists('kudos_qodef_button_typography_styles')) {
    /**
     * Typography styles for all button types
     */
    function kudos_qodef_button_typography_styles() {
        $selector = '.qodef-btn';
        $styles = array();

        $font_family = kudos_qodef_options()->getOptionValue('button_font_family');
        if(kudos_qodef_is_font_option_valid($font_family)) {
            $styles['font-family'] = kudos_qodef_get_font_option_val($font_family);
        }

        $text_transform = kudos_qodef_options()->getOptionValue('button_text_transform');
        if(!empty($text_transform)) {
            $styles['text-transform'] = $text_transform;
        }

        $font_style = kudos_qodef_options()->getOptionValue('button_font_style');
        if(!empty($font_style)) {
            $styles['font-style'] = $font_style;
        }

        $letter_spacing = kudos_qodef_options()->getOptionValue('button_letter_spacing');
        if($letter_spacing !== '') {
            $styles['letter-spacing'] = kudos_qodef_filter_px($letter_spacing).'px';
        }

        $font_weight = kudos_qodef_options()->getOptionValue('button_font_weight');
        if(!empty($font_weight)) {
            $styles['font-weight'] = $font_weight;
        }

        echo kudos_qodef_dynamic_css($selector, $styles);
    }

    add_action('kudos_qodef_style_dynamic', 'kudos_qodef_button_typography_styles');
}

if(!function_exists('kudos_qodef_button_outline_styles')) {
    /**
     * Generate styles for outline button
     */
    function kudos_qodef_button_outline_styles() {
        //outline styles
        $outline_styles   = array();
        $outline_selector = '.qodef-btn.qodef-btn-outline';

        if(kudos_qodef_options()->getOptionValue('btn_outline_text_color')) {
            $outline_styles['color'] = kudos_qodef_options()->getOptionValue('btn_outline_text_color');
        }

        if(kudos_qodef_options()->getOptionValue('btn_outline_border_color')) {
            $outline_styles['border-color'] = kudos_qodef_options()->getOptionValue('btn_outline_border_color');
        }

        echo kudos_qodef_dynamic_css($outline_selector, $outline_styles);

        //outline hover styles
        if(kudos_qodef_options()->getOptionValue('btn_outline_hover_text_color')) {
            echo kudos_qodef_dynamic_css(
                '.qodef-btn.qodef-btn-outline:not(.qodef-btn-custom-hover-color):hover',
                array('color' => kudos_qodef_options()->getOptionValue('btn_outline_hover_text_color').'!important')
            );
        }

        if(kudos_qodef_options()->getOptionValue('btn_outline_hover_bg_color')) {
            echo kudos_qodef_dynamic_css(
                '.qodef-btn.qodef-btn-outline:not(.qodef-btn-custom-hover-bg):hover',
                array('background-color' => kudos_qodef_options()->getOptionValue('btn_outline_hover_bg_color').'!important')
            );
        }

        if(kudos_qodef_options()->getOptionValue('btn_outline_hover_border_color')) {
            echo kudos_qodef_dynamic_css(
                '.qodef-btn.qodef-btn-outline:not(.qodef-btn-custom-border-hover):hover',
                array('border-color' => kudos_qodef_options()->getOptionValue('btn_outline_hover_border_color').'!important')
            );
        }
    }

    add_action('kudos_qodef_style_dynamic', 'kudos_qodef_button_outline_styles');
}

if(!function_exists('kudos_qodef_button_solid_styles')) {
    /**
     * Generate styles for solid type buttons
     */
    function kudos_qodef_button_solid_styles() {
        //solid styles
        $solid_selector = '.qodef-btn.qodef-btn-solid';
        $solid_styles = array();

        if(kudos_qodef_options()->getOptionValue('btn_solid_text_color')) {
            $solid_styles['color'] = kudos_qodef_options()->getOptionValue('btn_solid_text_color');
        }

        if(kudos_qodef_options()->getOptionValue('btn_solid_border_color')) {
            $solid_styles['border-color'] = kudos_qodef_options()->getOptionValue('btn_solid_border_color');
        }

        if(kudos_qodef_options()->getOptionValue('btn_solid_bg_color')) {
            $solid_styles['background-color'] = kudos_qodef_options()->getOptionValue('btn_solid_bg_color');
        }

        echo kudos_qodef_dynamic_css($solid_selector, $solid_styles);

        //solid hover styles
        if(kudos_qodef_options()->getOptionValue('btn_solid_hover_text_color')) {
            echo kudos_qodef_dynamic_css(
                '.qodef-btn.qodef-btn-solid:not(.qodef-btn-custom-hover-color):hover',
                array('color' => kudos_qodef_options()->getOptionValue('btn_solid_hover_text_color').'!important')
            );
        }

        if(kudos_qodef_options()->getOptionValue('btn_solid_hover_bg_color')) {
            echo kudos_qodef_dynamic_css(
                '.qodef-btn.qodef-btn-solid:not(.qodef-btn-custom-hover-bg):hover',
                array('background-color' => kudos_qodef_options()->getOptionValue('btn_solid_hover_bg_color').'!important')
            );
        }

        if(kudos_qodef_options()->getOptionValue('btn_solid_hover_border_color')) {
            echo kudos_qodef_dynamic_css(
                '.qodef-btn.qodef-btn-solid:not(.qodef-btn-custom-hover-bg):hover',
                array('border-color' => kudos_qodef_options()->getOptionValue('btn_solid_hover_border_color').'!important')
            );
        }
    }

    add_action('kudos_qodef_style_dynamic', 'kudos_qodef_button_solid_styles');
}

if(!function_exists('kudos_qodef_button_transparent_styles')) {
    /**
     * Generate styles for transparent type buttons
     */
    function kudos_qodef_button_transparent_styles() {
        //transparent styles

        $transparent_selector = '.qodef-btn.qodef-btn-transparent';
        $transparent_styles = array();

        if(kudos_qodef_options()->getOptionValue('btn_transparent_text_color')) {
            $transparent_styles['color'] = kudos_qodef_options()->getOptionValue('btn_transparent_text_color');
        }

        echo kudos_qodef_dynamic_css($transparent_selector, $transparent_styles);

        //solid hover styles
        if(kudos_qodef_options()->getOptionValue('btn_transparent_hover_text_color')) {
            echo kudos_qodef_dynamic_css(
                '.qodef-btn.qodef-btn-transparent:not(.qodef-btn-custom-hover-color):hover',
                array('color' => kudos_qodef_options()->getOptionValue('btn_transparent_hover_text_color').'!important')
            );
        }

    }

    add_action('kudos_qodef_style_dynamic', 'kudos_qodef_button_transparent_styles');
}