<?php
namespace KudosQodef\Modules\Shortcodes\TimelineItem;

use KudosQodef\Modules\Shortcodes\Lib\ShortcodeInterface;

class TimelineItem implements ShortcodeInterface{
	private $base;

	function __construct() {
		$this->base = 'qodef_timeline_item';
		add_action('vc_before_init', array($this, 'vcMap'));
	}
	public function getBase() {
		return $this->base;
	}
	
	public function vcMap() {
		if(function_exists('vc_map')){
			vc_map( 
				array(
					'name' => esc_html__('Select Timeline Item', 'select-core'),
					'base' => $this->base,
					'as_child' => array('only' => 'qodef_timeline_item'),
					'as_parent' => array('except' => 'vc_row, vc_accordion, no_cover_boxes, no_portfolio_list, no_portfolio_slider'),
					'content_element' => true,
					'category' => esc_html__('by SELECT', 'select-core'),
					'icon' => 'icon-wpb-timeline-item extended-custom-icon',
					'show_settings_on_create' => true,
					'params' =>
						array(
							array(
								'type'        => 'textfield',
								'heading'     => esc_html__('Item Title', 'select-core'),
								'admin_label' => true,
								'param_name'  => 'item_title'
							),
							array(
								'type' => 'dropdown',
								'heading' => esc_html__('Title Tag', 'select-core'),
								'param_name' => 'title_tag',
								'value' => array(
									''   => '',
									esc_html__('h2', 'select-core') => 'h2',
									esc_html__('h3', 'select-core') => 'h3',
									esc_html__('h4', 'select-core') => 'h4',
									esc_html__('h5', 'select-core') => 'h5',
									esc_html__('h6', 'select-core') => 'h6',
								),
								'description' => '',
								'dependency' => array( 'element' => 'item_title', 'not_empty' => true )
							),
							array(
								'type'        => 'textfield',
								'heading'     => esc_html__('Item Subtitle', 'select-core'),
								'admin_label' => true,
								'param_name'  => 'item_subtitle'
							),
							array(
								'type'       => 'textarea',
								'heading'    => esc_html__('Item Text', 'select-core'),
								'param_name' => 'item_text'
							),
						)
				)
			);			
		}
	}

	public function render($atts, $content = null) {
		$args = array(
			'item_title' => '',
			'item_subtitle' => '',
			'title_tag' => 'h5',
			'item_text' => ''
		);

		$args = array_merge($args, kudos_qodef_icon_collections()->getShortcodeParams());
		$params = shortcode_atts($args, $atts);
		extract($params);

		$iconPackName = kudos_qodef_icon_collections()->getIconCollectionParamNameByKey($params['icon_pack']);

		$params['icon'] = $params[$iconPackName];
		$params['title_tag'] = $this->getValidTitleTag($params, $args);

		$html = select_core_get_shortcode_template_part('templates/timeline-item-template', 'timeline', '', $params);

		return $html;
	}

	/**
	 * Return correct heading value. If provided heading isn't valid get the default one
	 *
	 * @param $params
	 * @param $args
	 */
	private function getValidTitleTag($params, $args) {

		$headings_array = array('h2', 'h3', 'h4', 'h5', 'h6');
		return (in_array($params['title_tag'], $headings_array)) ? $params['title_tag'] : $args['title_tag'];

	}

}
