<?php
namespace KudosQodef\Modules\Shortcodes\Timeline;

use KudosQodef\Modules\Shortcodes\Lib\ShortcodeInterface;

/**
 * Class Timeline
 */
class Timeline implements ShortcodeInterface{
	private $base; 
	
	function __construct() {
		$this->base = 'qodef_timeline';

		add_action('vc_before_init', array($this, 'vcMap'));
	}
	
	/**
		* Returns base for shortcode
		* @return string
	 */

	public function getBase() {
		return $this->base;
	}

	public function vcMap() {
		if(function_exists('vc_map')){
			vc_map(
				array(
					'name' => esc_html__('Select Timeline', 'select-core'),
					'base' => $this->base,
					'category' => esc_html__('by SELECT', 'select-core'),
					'icon' => 'icon-wpb-timeline extended-custom-icon',
					'as_parent' => array('only' => 'qodef_timeline_item'),
					'js_view' => 'VcColumnView',
					'params' => array_merge(
						\KudosQodefIconCollections::get_instance()->getVCParamsArray(),
						array(
							array(
								'type' => 'colorpicker',
								'heading' => esc_html__('Icon Color', 'select-core'),
								'param_name' => 'icon_color',
								'description' => ''
							),
							array(
								'type'        => 'dropdown',
								'admin_label' => true,
								'heading'     => esc_html__('Item Alignment', 'select-core'),
								'param_name'  => 'item_alignment',
								'value'       => array(
									esc_html__('Left', 'select-core')  => 'left',
									esc_html__('Right', 'select-core') => 'right'
								),
								'save_always' => true
							),
						)
					)
				)
			);
		}
	}

	public function render($atts, $content = null) {
		
		$args = array(
            'icon_color'    	=> '',
			'item_alignment'	=> 'left'
        );

		$args = array_merge($args, kudos_qodef_icon_collections()->getShortcodeParams());

		$params = shortcode_atts($args, $atts);

        extract($params);
		$iconPackName = kudos_qodef_icon_collections()->getIconCollectionParamNameByKey($params['icon_pack']);

        $html = '';

        $timeline_classes = array();
        $timeline_classes[] = 'qodef-timeline-holder';
		$params['icon'] = $params[$iconPackName];
		$params['icon_style'] = $this->generateIconStyles($params);

		if(!empty($params['item_alignment'])) {
			switch($params['item_alignment']) {
				case 'left':
					$timeline_classes[] = 'qodef-timeline-align-left';
					break;
				case 'right':
					$timeline_classes[] = 'qodef-timeline-align-right';
					break;
				default:
					break;
			}
		}

		$timeline_class = implode(' ', $timeline_classes);

        $html .= '<div '. kudos_qodef_get_class_attribute($timeline_class) . '>';
			$html .= select_core_get_shortcode_template_part('templates/icon', 'timeline', '', $params);
            $html .= do_shortcode($content);
        $html .= '</div>';

        return $html;

	}

	/**
	 * Generates icon styles array
	 *
	 * @param $params
	 *
	 * @return string
	 */
	private function generateIconStyles($params) {
		$iconStyles = array();

		if(!empty($params['icon_color'])) {
			$iconStyles[] = 'background-color: '.$params['icon_color'];
		}

		return implode(';', $iconStyles);
	}

}